@@ -1,7 +1,6 @@
 import ipywidgets as widgets
 from IPython.core.display import clear_output
 from ipywidgets import interactive, fixed, HBox, Layout, VBox
-from replifactory.culture.culture_functions import dilute_adjust_drug1
 import pandas as pd
 import numpy as np
 
@@ -241,36 +240,6 @@ class ValveButtons:
         self.close_all.icon = "fa-tint-slash"
 
 
-class DilutionWidget:
-    def __init__(self, device):
-        self.device = device
-        self.vial = widgets.Dropdown(options=[1, 2, 3, 4, 5, 6, 7], index=None, description="Vial")
-        self.target_concentration = widgets.FloatSlider(disabled=True, description="concentration")
-        self.vial.observe(self.handle_vial_change, names="value")
-        self.button = widgets.Button(description="make dilution", icon="fa-vial")
-        self.button.on_click(self.handle_button)
-        self.widget = VBox([self.vial, self.target_concentration, self.button])
-
-    def handle_button(self, button):
-        self.button.disabled = True
-        self.button.description = "diluting..."
-        c = self.device.cultures[self.vial.value]
-        dilute_adjust_drug1(culture=c, target_concentration=self.target_concentration.value)
-        self.button.disabled = False
-        self.button.description = "make dilution"
-
-    def handle_vial_change(self, change):
-        c = self.device.cultures[change["new"]]
-        dilution_factor = (c.default_dilution_volume + c.dead_volume) / c.dead_volume
-        self.target_concentration.min = c.medium2_concentration / dilution_factor
-        stock_c = c.device.pump2.stock_concentration
-        self.target_concentration.value = c.medium2_concentration
-        self.target_concentration.max = (
-                                                    c.medium2_concentration * c.dead_volume + c.default_dilution_volume * stock_c) / (
-                                                    c.dead_volume + c.default_dilution_volume)
-        self.target_concentration.disabled = False
-
-
 # class LaserWidget:
 #     def __init__(self, device, main_gui):
 #         self.device = device
@@ -341,7 +310,7 @@ class ODWidget:
             button.on_click(self.make_od_button_function(vial))
 
         self.bottom = HBox([VBox([self.measure_buttons[vial], self.od_outputs[vial]],
-                       layout=Layout(align_items='center', width='110px', height="90px")) for vial in range(1,8)])
+                       layout=Layout(align_items='center', width='110px', height="120px")) for vial in range(1,8)])
         self.widget = HBox([self.measure_all, self.bottom], layout=box_layout)
 
     def measure_all_button_action(self, button):
@@ -355,12 +324,12 @@ class ODWidget:
                 bg = self.device.od_sensors[vial].measure_background_intensity()[0]
                 tr = self.device.od_sensors[vial].measure_transmitted_intensity()[0]
                 sig = tr-bg
-                print("%4.1f mV\nbg: %3.1fmV" % (tr, bg))
+                print("sig:%4.1fmV\nbg:%3.1fmV" % (tr, bg))
                 od = self.device.od_sensors[vial].calibration_function(sig)
                 if od is not None:
-                    print("OD: %.4f" % od)
+                    print("OD:%.4f" % od)
                 else:
-                    print("OD: ?")
+                    print("OD:?")
         return button_function
 
 
@@ -428,9 +397,16 @@ class SinglePumpWidget:
             self.conc_text.disabled = False
             self.volume_text.value = self.pump.stock_volume
             self.conc_text.value = self.pump.stock_concentration
+
         else:
-            self.volume_text.disabled = True
-            self.conc_text.disabled = True
+            if pd.isnull(self.pump.device.directory):
+                self.volume_text.disabled = True
+                self.conc_text.disabled = True
+            else:
+                self.volume_text.disabled = False
+                self.conc_text.disabled = False
+                self.volume_text.value = self.pump.stock_volume
+                self.conc_text.value = self.pump.stock_concentration
 
     def update_volume_bar(self):
         vol = self.pump.stock_volume
@@ -470,7 +446,7 @@ class SinglePumpWidget:
                 rots = float(self.main_pump_widget.pumped_rotations.value.split()[0])
             else:
                 if self.main_pump_widget.pumped_rotations.value == self.main_pump_widget.pumped_rotations.options[-2]:
-                    self.pump.run(0.1)
+                    self.pump.run(speed=0.1)
                     return
                 else:
                     vol = self.main_pump_widget.pumped_volume.value
