@@ -2,17 +2,15 @@ import ipywidgets as widgets
 import inspect, sys
 from ipywidgets import VBox, Layout, HBox
 from IPython.core.display import clear_output
-from replifactory.culture.morbidostat import MorbidostatCulture
-from replifactory.culture.turbidostat import TurbidostatCulture
-from replifactory.culture.chemostat import ChemostatCulture
 
-from replifactory.culture.endurance import EnduranceStressCulture
+from replifactory.culture.culture_functions import dilute_adjust_drug1
+
 from replifactory.culture.blank import BlankCulture
-from replifactory.culture.batch import BatchCulture
-# from replifactory.culture.patients import PatientCulture
 import os
 import time
 
+from replifactory.GUI.graph_tab import CulturePlotWidget
+
 
 class ExperimentProgramTab:
     title = "Experiment"
@@ -63,11 +61,17 @@ class ExperimentProgramTab:
             title = widgets.HTML('<b>%s:</b>' % absdir,
                                  layout=Layout(width="400px"))
 
-            vials = [VialConfigWidget(program_viewer_tab=self, vial_number=v).widget for v in range(1, 8)]
+            vials = []
+            for v in range(1, 8):
+                vials += [VBox([VialConfigWidget(program_viewer_tab=self, vial_number=v).widget,
+                                VialStatusWidget(device=self.main_gui.device, vial_number=v).widget,
+                                CulturePlotWidget(main_gui=self.main_gui,vial_number=v).widget,
+                                DilutionWidget(device=self.main_gui.device).widget
+                                ])]
             tabs = widgets.Tab()
             tabs.children = vials
             [tabs.set_title(i, "Vial %d" % (i+1)) for i in range(7)]
-            self.widget = VBox([title, tabs])
+            self.widget = VBox([title, tabs], layout=Layout(width="800px"))
             self.main_gui.update()
         except:
             self.widget = widgets.HTML('<b>Experiment GUI error</b>', layout=Layout(width="400px"))
@@ -111,13 +115,16 @@ class ExperimentProgramTab:
 
 
 def get_culture_options():
-    culture_options = [BatchCulture, ChemostatCulture, TurbidostatCulture, MorbidostatCulture,
-                       EnduranceStressCulture, BlankCulture]  # BlankCulture, PatientCulture
-    for name, obj in inspect.getmembers(sys.modules["__main__"]):
+    # culture_options = [BatchCulture, ChemostatCulture, TurbidostatCulture, MorbidostatCulture,
+    #                    EnduranceStressCulture, LagoonCulture, BlankCulture]  # BlankCulture, PatientCulture
+    culture_options = []
+    for name, obj in inspect.getmembers(sys.modules["__main__"]) + \
+                     inspect.getmembers(sys.modules["replifactory.culture"]):
         if inspect.isclass(obj):
             if issubclass(obj, BlankCulture):
                 if obj not in culture_options:
                     culture_options += [obj]
+    culture_options = sorted(culture_options,key=lambda x: str(x))
     return culture_options
 
 
@@ -268,3 +275,62 @@ class VialConfigWidget:
                 change.new(directory=self.main_gui.experiment.directory, vial_number=self.vial_number)
         self.widget = self.__init__(program_viewer_tab=self.program_viewer_tab, vial_number=self.vial_number)
         self.program_viewer_tab.update()
+
+
+class VialStatusWidget:
+    """
+    Shows status of one culture
+    """
+    def __init__(self, device, vial_number):
+        self.device = device
+        self.vial_number = vial_number
+        self.refresh = widgets.Button(icon="fa-info", tooltip="refresh status", button_style="info",
+                                      layout=Layout(width="35px"))
+        self.refresh.on_click(self.show_status)
+
+        self.clear = widgets.Button(icon="fa-eye-slash", tooltip="hide status text", button_style="info", layout=Layout(width="45px"))
+        self.clear.on_click(self.handle_clear_button)
+
+        self.output = widgets.Output(layout=Layout(width="600px"))
+        self.widget = HBox([self.refresh, self.clear, self.output])
+
+    def handle_clear_button(self,button):
+        with self.output:
+            clear_output()
+
+    def show_status(self, button):
+        with self.output:
+            clear_output()
+            self.device.cultures[self.vial_number].show_parameters(increase_verbosity=True)
+
+
+class DilutionWidget:
+    def __init__(self, device):
+        self.device = device
+        self.vial = widgets.Dropdown(options=[1, 2, 3, 4, 5, 6, 7], index=None, description="Vial")
+        self.target_concentration = widgets.FloatSlider(disabled=True, description="concentration")
+        self.vial.observe(self.handle_vial_change, names="value")
+        self.button = widgets.Button(description="make dilution", tooltip="USE WITH CAUTION!!! wait for background dilution thread to finish remaining jobs and make dilution in main thread", icon="fa-vial", button_style="danger")
+        self.button.on_click(self.handle_button)
+        self.widget = VBox([self.vial, self.target_concentration, self.button])
+
+    def handle_button(self, button):
+        try:
+            self.button.disabled = True
+            self.button.description = "diluting..."
+            c = self.device.cultures[self.vial.value]
+            dilute_adjust_drug1(culture=c, target_concentration=self.target_concentration.value)
+        finally:
+            self.button.disabled = False
+            self.button.description = "make dilution"
+
+    def handle_vial_change(self, change):
+        c = self.device.cultures[change["new"]]
+        dilution_factor = (c.default_dilution_volume + c.dead_volume) / c.dead_volume
+        self.target_concentration.min = c.medium2_concentration / dilution_factor
+        stock_c = c.device.pump2.stock_concentration
+        self.target_concentration.value = c.medium2_concentration
+        self.target_concentration.max = (
+                                                    c.medium2_concentration * c.dead_volume + c.default_dilution_volume * stock_c) / (
+                                                    c.dead_volume + c.default_dilution_volume)
+        self.target_concentration.disabled = False
\ No newline at end of file
