@@ -1,11 +1,11 @@
-__version__ = "0.0.38"
+__version__ = "0.0.50"
 from .device.base_device import BaseDevice
 from .device.morbidostat_device import MorbidostatDevice
-from .culture import TurbidostatCulture, MorbidostatCulture
+# from .culture import TurbidostatCulture, MorbidostatCulture
 from .experiment import Experiment
 from .GUI.main_gui import MainGuiBuilder as Gui
 # from .GUI.main_gui import open_gui
-from .GUI.notifier import Notifier
+# from .GUI.notifier import Notifier
 from . import util
 from IPython.display import display
 import subprocess
