@@ -22,6 +22,7 @@ class ChemostatCulture(BlankCulture):
         self.dead_volume = dead_volume
         #         self.od_max_limit = od_max_limit
         self.dilution_period_mins = 30
+        self.initial_dilution_od = 0.3
         self.medium2_c_target = 0
 
         # Running parameters
@@ -48,7 +49,8 @@ class ChemostatCulture(BlankCulture):
         if self.is_active():
             self.update_growth_rate()
             if self._last_dilution_start_time is None:
-                self.make_chemostat_dilution()  # initial dilution
+                if self.od > self.initial_dilution_od:
+                    self.make_chemostat_dilution()  # initial dilution
             else:
                 if time.time() - self._last_dilution_start_time >= self.dilution_period_mins * 60 - 55:
                     self.make_chemostat_dilution()
@@ -68,9 +70,10 @@ class ChemostatCulture(BlankCulture):
         td = np.log(2) / dilution_rate_per_hr
 
         t = f"""The {self.dead_volume:.1f}mL culture is diluted with {self.default_dilution_volume:.1f}mL every {self.dilution_period_mins:.0f} min.
-      dilution factor: 1/{dilution_factor:.2f} ({generations_per_dilution:.2f} generations/dilution) 
-           medium use: {flow_rate:.2f} mL/h  ({1000/generations_per_l:.1f} mL/generation)
-        doubling time: {td*60:.1f} min (growth rate: {dilution_rate_per_hr:.2f}/h)"""
+dilution factor: 1/{dilution_factor:.2f} ({generations_per_dilution:.2f} generations/dilution) 
+     medium use: {flow_rate:.2f} mL/h  ({1000/generations_per_l:.1f} mL/generation)
+  doubling time: {td*60:.1f} min (growth rate: {dilution_rate_per_hr:.2f}/h)
+  """
         return t
 
     def status_text(self):
