@@ -21,6 +21,7 @@ from replifactory.device.thermometers import Thermometers
 from replifactory.device.valves import Valves
 from replifactory.device.dilution import make_dilution
 from replifactory.culture.blank import BlankCulture
+from replifactory.culture.lagoon import LagoonCulture
 
 from replifactory.util import CultureDict
 from replifactory.loading import save_object, load_config, load_object
@@ -50,8 +51,8 @@ class BaseDevice:
         self.dilution_worker = None
         self.od_worker = None
 
-        # self.hard_stop_trigger = False
-        # self.soft_stop_trigger = False
+        self.hard_stop_trigger = False
+        self.soft_stop_trigger = False
 
         self.i2c = None
         self.spi = None
@@ -147,6 +148,8 @@ class BaseDevice:
             print("Device %s connection established" % ftdi_address)
             self.dilution_worker = QueueWorker(device=self, worker_name="dilution")
             self.od_worker = QueueWorker(device=self, worker_name="od")
+            self.hard_stop_trigger = False
+            self.soft_stop_trigger = False
             if self.directory is not None and fit_calibration:
                 try:
                     self.fit_calibration_functions()
@@ -206,6 +209,12 @@ class BaseDevice:
                 3: self.pump3,
                 4: self.pump4}
 
+    def stop_pumps(self):
+        self.pump1.stop()
+        self.pump2.stop()
+        self.pump3.stop()
+        self.pump4.stop()
+
     def make_dilution(self, vial, pump1_volume=0, pump2_volume=0, pump3_volume=0, extra_vacuum=5):
         make_dilution(device=self, vial=vial, pump1_volume=pump1_volume, pump2_volume=pump2_volume,
                       pump3_volume=pump3_volume, extra_vacuum=extra_vacuum)
@@ -248,28 +257,51 @@ class BaseDevice:
         self.lock_pumps.release()
         self.locks_vials[vial_number].release()
 
+    def release_locks(self):
+        if self.is_pumping():
+            self.stop_pumps()
+            print("Stopped pumps")
+        for v in range(1, 8):
+            try:
+                if self.locks_vials[v].locked():
+                    self.locks_vials[v].release()
+                    print("released vial %d lock"%v)
+            except:
+                pass
+        if self.lock_pumps.locked():
+            self.lock_pumps.release()
+            print("released pump lock")
+
     def flush_tubing(self):
         """
         to prevent tube drying
         """
 
         def queued_function():
-            for v in range(1, 8):
-                c = self.cultures[v]
-                flush_volumes = {1: 0, 2: 0, 3: 0}  # pump: ml
+            if self.is_lagoon_device():
+                for v in range(1, 8):
+                    self.cultures[v].flush_culture()
+            else:
+                for v in range(1, 8):
+                    c = self.cultures[v]
+                    flush_volumes = {1: 0, 2: 0, 3: 0}  # pump: ml
 
-                tstart = c.experiment_start_time
-                for pump_number in self.active_pumps:
-                    tdil = np.float32(c._time_last_dilution[pump_number])
-                    last_pump_time = np.nanmax([tdil, tstart])
-                    if (time.time() - last_pump_time) > self.drying_prevention_pump_period_hrs * 3600:
-                        flush_volumes[pump_number] = self.drying_prevention_pump_volume
-
-                if flush_volumes[1] > 0 or flush_volumes[2] or flush_volumes[3] > 0:
-                    c.dilute(pump1_volume=flush_volumes[1], pump2_volume=flush_volumes[2],
-                             pump3_volume=flush_volumes[3], extra_vacuum=3)
+                    tstart = c.experiment_start_time
+                    for pump_number in self.active_pumps:
+                        tdil = np.float32(c._time_last_dilution[pump_number])
+                        last_pump_time = np.nanmax([tdil, tstart])
+                        if (time.time() - last_pump_time) > self.drying_prevention_pump_period_hrs * 3600:
+                            flush_volumes[pump_number] = self.drying_prevention_pump_volume
+                    if flush_volumes[1] > 0 or flush_volumes[2] or flush_volumes[3] > 0:
+                        c.dilute(pump1_volume=flush_volumes[1], pump2_volume=flush_volumes[2],
+                                 pump3_volume=flush_volumes[3], extra_vacuum=3)
         self.dilution_worker.queue.put(queued_function)
 
+    def is_lagoon_device(self):
+        for v in range(1, 8):
+            if type(self.cultures[v]) is LagoonCulture:
+                return True
+
     def is_pumping(self):
         return any(p.is_pumping() for p in [self.pump1, self.pump2, self.pump3, self.pump4])
 
